Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewEchoLoggerMiddleware ¶
func NewEchoLoggerMiddleware(baseLogger *zerolog.Logger) echo.MiddlewareFunc
Types ¶
type EchoLoggerMiddleware ¶
type EchoLoggerMiddleware struct {
// Level is the level that normal requests will be logged with.
// This can be set to Disabled to only log unsuccessful requests.
Level zerolog.Level
// ErrorLevel is the level that unsuccessful requests will be logged with.
// This can be set to Disabled to only log successful requests.
ErrorLevel zerolog.Level
// Prefix will be prepended to the message string of all log messages from this adapter.
Prefix string
// contains filtered or unexported fields
}
func (*EchoLoggerMiddleware) GetMiddlewareFunc ¶
func (l *EchoLoggerMiddleware) GetMiddlewareFunc() echo.MiddlewareFunc
Click to show internal directories.
Click to hide internal directories.